@@ -39,30 +39,38 @@ def get_document(las_client: Client, document_id, download_content, output_conte
         return {**document_resp, 'content': document_resp['content'][:10] + '... [TRUNCATED]'}
 
 
-def list_documents(las_client: Client, batch_id, consent_id, max_results, next_token):
+def list_documents(las_client: Client, batch_id, consent_id, dataset_id, max_results, next_token):
     return las_client.list_documents(
         batch_id=batch_id,
         consent_id=consent_id,
+        dataset_id=dataset_id,
         max_results=max_results,
         next_token=next_token,
     )
 
 
-def delete_documents(las_client: Client, batch_id, consent_id, next_token, max_results):
+def delete_documents(las_client: Client, batch_id, consent_id, dataset_id, next_token, max_results):
     return las_client.delete_documents(
         batch_id=batch_id,
         consent_id=consent_id,
+        dataset_id=dataset_id,
         next_token=next_token,
         max_results=max_results,
+        delete_all=False if max_results else True,
     )
 
 
+def delete_document(las_client: Client, document_id):
+    return las_client.delete_document(document_id)
+
+
 def create_document(
     las_client: Client,
     document_path,
     content_type,
     consent_id,
     batch_id,
+    dataset_id,
     ground_truth_fields,
     ground_truth_path,
 ):
@@ -80,13 +88,14 @@ def create_document(
         content_type,
         consent_id=consent_id,
         batch_id=batch_id,
+        dataset_id=dataset_id,
         ground_truth=ground_truth,
     )
 
 
-def update_document(las_client: Client, document_id, ground_truth_fields, ground_truth_path):
+def update_document(las_client: Client, document_id, dataset_id, ground_truth_fields, ground_truth_path):
     ground_truth = _create_ground_truth_dict(ground_truth_fields, ground_truth_path)
-    return las_client.update_document(document_id, ground_truth)
+    return las_client.update_document(document_id, dataset_id=dataset_id, ground_truth=ground_truth)
 
 
 def create_documents_parser(subparsers):
@@ -102,6 +111,7 @@ def create_documents_parser(subparsers):
     list_documents_parser = subparsers.add_parser('list')
     list_documents_parser.add_argument('--batch-id', nargs='+')
     list_documents_parser.add_argument('--consent-id', nargs='+')
+    list_documents_parser.add_argument('--dataset-id', nargs='+')
     list_documents_parser.add_argument('--max-results', '-m', type=int)
     list_documents_parser.add_argument('--next-token', '-n', type=str)
     list_documents_parser.set_defaults(cmd=list_documents)
@@ -111,6 +121,7 @@ def create_documents_parser(subparsers):
     create_document_parser.add_argument('--content-type')
     create_document_parser.add_argument('--consent-id')
     create_document_parser.add_argument('--batch-id')
+    create_document_parser.add_argument('--dataset-id')
     create_document_ground_truth_group = create_document_parser.add_mutually_exclusive_group(required=False)
     create_document_ground_truth_group.add_argument('--ground-truth-fields', metavar='KEY=VALUE', nargs='+')
     create_document_ground_truth_group.add_argument('--ground-truth-path', type=str, help='Path to JSON file')
@@ -118,14 +129,20 @@ def create_documents_parser(subparsers):
 
     update_document_parser = subparsers.add_parser('update')
     update_document_parser.add_argument('document_id')
+    update_document_parser.add_argument('--dataset-id')
     update_document_ground_truth_group = update_document_parser.add_mutually_exclusive_group(required=False)
     update_document_ground_truth_group.add_argument('--ground-truth-fields', metavar='KEY=VALUE', nargs='+')
     update_document_ground_truth_group.add_argument('--ground-truth-path', type=str, help='Path to JSON file')
     update_document_parser.set_defaults(cmd=update_document)
 
-    delete_documents_parser = subparsers.add_parser('delete')
+    delete_document_parser = subparsers.add_parser('delete')
+    delete_document_parser.add_argument('document_id')
+    delete_document_parser.set_defaults(cmd=delete_document)
+
+    delete_documents_parser = subparsers.add_parser('delete-all')
     delete_documents_parser.add_argument('--consent-id', nargs='+')
     delete_documents_parser.add_argument('--batch-id', nargs='+')
+    delete_documents_parser.add_argument('--dataset-id', nargs='+')
     delete_documents_parser.add_argument('--max-results', '-m', type=int)
     delete_documents_parser.add_argument('--next-token', '-n', type=str)
     delete_documents_parser.set_defaults(cmd=delete_documents)
