@@ -34,10 +34,29 @@ def get_transition(las_client: Client, transition_id):
     return las_client.get_transition(transition_id)
 
 
-def update_transition(las_client: Client, transition_id, in_schema_path=None, out_schema_path=None, **optional_args):
+def update_transition(
+    las_client: Client,
+    transition_id,
+    in_schema_path=None,
+    out_schema_path=None,
+    assets_path=None,
+    environment_path=None,
+    environment_secrets=None,
+    **optional_args,
+):
     in_schema = json.loads(pathlib.Path(in_schema_path).read_text()) if in_schema_path else None
     out_schema = json.loads(pathlib.Path(out_schema_path).read_text()) if out_schema_path else None
-    return las_client.update_transition(transition_id, in_schema=in_schema, out_schema=out_schema, **optional_args)
+    assets = json.loads(pathlib.Path(assets_path).read_text()) if assets_path else None
+    environment = json.loads(pathlib.Path(environment_path).read_text()) if environment_path else None
+    return las_client.update_transition(
+        transition_id,
+        in_schema=in_schema,
+        out_schema=out_schema,
+        assets=assets,
+        environment=environment,
+        environment_secrets=environment_secrets,
+        **optional_args,
+    )
 
 
 def execute_transition(las_client: Client, transition_id):
@@ -62,7 +81,8 @@ def update_transition_execution(
     execution_id,
     status,
     error_path=None,
-    output_path=None
+    output_path=None,
+    start_time=None,
 ):
     output_dict = json.loads(pathlib.Path(output_path).read_text()) if output_path else None
     error_dict = json.loads(pathlib.Path(error_path).read_text()) if error_path else None
@@ -72,9 +92,14 @@ def update_transition_execution(
         status,
         output=output_dict,
         error=error_dict,
+        start_time=start_time,
     )
 
 
+def send_heartbeat(las_client: Client, transition_id, execution_id):
+    return las_client.send_heartbeat(transition_id, execution_id)
+
+
 def create_transitions_parser(subparsers):
     parser = subparsers.add_parser('transitions')
     subparsers = parser.add_subparsers()
@@ -103,6 +128,19 @@ def create_transitions_parser(subparsers):
     update_parser.add_argument('--name', type=nullable, default=NotProvided)
     update_parser.add_argument('--in-schema-path')
     update_parser.add_argument('--out-schema-path')
+    update_parser.add_argument(
+        '--assets-path',
+        help='Path to json file with str keys and values that are assetIds, only possible for a manual transition'
+    )
+    update_parser.add_argument(
+        '--environment-path',
+        help='Path to json file with environment variables, only possible for a docker transition',
+    )
+    update_parser.add_argument(
+        '--environment-secrets',
+        nargs='+',
+        help='secretIds that that will be used as environment variables, only possible for a docker transition',
+    )
     update_parser.add_argument('--description', type=nullable, default=NotProvided)
     update_parser.set_defaults(cmd=update_transition)
 
@@ -110,7 +148,10 @@ def create_transitions_parser(subparsers):
     execute_parser.add_argument('transition_id')
     execute_parser.set_defaults(cmd=execute_transition)
 
-    delete_parser = subparsers.add_parser('delete', description='Will fail if transition is in use by one or more workflows')
+    delete_parser = subparsers.add_parser(
+        'delete',
+        description='Will fail if transition is in use by one or more workflows',
+    )
     delete_parser.add_argument('transition_id')
     delete_parser.set_defaults(cmd=delete_transition)
 
@@ -135,6 +176,12 @@ def create_transitions_parser(subparsers):
     update_execution_parser.add_argument('status', choices=['succeeded', 'failed', 'rejected', 'retry'])
     update_execution_parser.add_argument('--output_path', '-o')
     update_execution_parser.add_argument('--error_path', '-e')
+    update_execution_parser.add_argument('--start-time')
     update_execution_parser.set_defaults(cmd=update_transition_execution)
 
+    send_heartbeat_parser = subparsers.add_parser('heartbeat')
+    send_heartbeat_parser.add_argument('transition_id')
+    send_heartbeat_parser.add_argument('execution_id')
+    send_heartbeat_parser.set_defaults(cmd=send_heartbeat)
+
     return parser
